//
//  CDIOnboardTheme.swift
//  tecnonutri
//
//  Created by Thales Frigo on 03/09/20.
//  Copyright © 2020 Grupo Minha Vida. All rights reserved.


import UIKit
import CDIOnboard
import CDIKit
import CDIWorkout
import CDIMind
import CDIChallenge
import CDIJourney
import CDIEating
import CDIConfig
import CDIVitat
import CDIPlatform
import CDIMeet

struct CDITheme: CDIAppearance {
    
    var config: ConfigTheme {
        CDIConfigTheme()
    }
    
    var meal: MealTheme {
        CDIMealTheme()
    }
    
    var workout: WorkoutTheme {
        CDIWorkoutTheme()
    }
    
    var meditation: MeditationTheme {
        CDIMeditationTheme()
    }
    
    var diary: DiaryTheme {
        CDIDiaryTheme()
    }
    
    var journey: JourneyTheme {
        CDIJourneyTheme()
    }
    
    var challenge: ChallengeTheme {
        CDIChallengeTheme()
    }
    
    var kit: KitTheme {
        return self
    }
    
    var onboard: OnboardTheme {
        return self
    }
    
    var vitat: VitatTheme {
        CDIVitatTheme()
    }
    
    var meet: MeetTheme {
        return CDIMeetTheme()
    }
}

extension CDITheme: OnboardTheme {
    var chatbotTitle: String {
        "Vitat"
    }

    var chatbotTitleColor: UIColor {
        .black
    }

    var leftButtonColor: UIColor {
        .systemBlue
    }


    var backgroundColor: UIColor {
        .white
    }

    var backgroundButtons: UIColor {
        .neuteral()
    }

    var receiver: ReceiverBubbleTheme {
        CDIOnboardReceiverTheme()
    }

    var sender: SenderBubbleTheme {
        CDIOnboardSenderTheme()
    }

    var answer: AnswerTheme {
        CDIOnboardAnswerTheme()
    }

    var input: InputTheme {
        CDIOnboardInputTheme()
    }
}

struct CDIOnboardReceiverTheme: ReceiverBubbleTheme {

    var rTextFont: UIFont {
        .boldSystemFont(ofSize: 15)
    }

    var rBubbleColor: UIColor {
        .brandPure()
    }

    var rTextColor: UIColor {
        .white
    }
}

struct CDIOnboardSenderTheme: SenderBubbleTheme {

    var sAvatarImage: UIImage? {
        UIImage(named: "nutri_small")
    }

    var sTextFont: UIFont {
        .systemFont(ofSize: 15)
    }

    var sBubbleColor: UIColor {
        .neuteral()
    }

    var sTextColor: UIColor {
        .primaryText()
    }

    var sTitleColor: UIColor? {
        .inactiveStates()
    }

    var sTimestampColor: UIColor? {
        .inactiveStates()
    }
}

struct CDIOnboardAnswerTheme: AnswerTheme {

    var backgroundColor: UIColor {
        .white
    }

    var tintColor: UIColor {
        .neutralDark()
    }
}

struct CDIOnboardInputTheme: InputTheme {
    var backgroundColor: UIColor {
        .inputBackground()
    }

    var cursorColor: UIColor {
        .accent()
    }

    var textColor: UIColor {
        .primaryText()
    }

    var actionBackgroundColor: UIColor {
        .pure()
    }

    var actionTintColor: UIColor {
        .darkest()
    }
}

extension CDITheme: KitTheme {
    var primaryButton: UIColor {
        .pure()
    }

    var primaryButtonText: UIColor {
        .darkest()
    }

    var darkest: UIColor {
        .darkest()
    }

    var pure: UIColor {
        .pure()
    }


    var secondary: UIColor {
        .black40()
    }

    var primary: UIColor {
        .darkest()
    }

    var action: UIColor {
        .pure()
    }

    var inactive: UIColor {
        .inactiveStates()
    }

    var surface: UIColor {
        .surface()
    }

    var background: UIColor {
        .background()
    }

    var secondaryText: UIColor {
        .secondaryText()
    }

    var primaryText: UIColor {
        .primaryText()
    }

    var tertiaryText: UIColor {
        .tertiaryText()
    }

    var fourthText: UIColor {
        .fourthText()
    }
    
    var emptyImage: UIImage? {
        UIImage(named: "ic_empty_star")
    }
    
    var filledImage: UIImage? {
        UIImage(named: "ic_filled_star")
    }
    
    var appStoreLink: URL? {
        URL(string: "itms-apps://apple.com/app/id1543038009")
    }

    var navigation: CDINavigationStyle {
        CDINavigationStyle(
            viewBackgroundColor: .navBar(),
            navBarBackgroundColor: .navBar(),
            navBarColor: .navBar(),
            navBarTintColor: .black,
            navBarTranslucent: false,
            navBarOpaque: true,
            navBarTitleColor: .primaryText(),
            navShadowImage: UIImage(),
            navBackgroundImage: UIImage(),
            statusBarStyle: .default)
    }

    var font: FontTheme {
        CDIFontTheme()
    }
}

struct CDIFontTheme: FontTheme {

    var primaryFamily: String {
        "Livvic"
    }
}

struct CDIWorkoutTheme: WorkoutTheme {

    var tintColor: UIColor {
        .pure()
    }

    var navigation: CDINavigationStyle {
        CDINavigationStyle(
            viewBackgroundColor: .white,
            navBarBackgroundColor: .white,
            navBarColor: .white,
            navBarTintColor: .systemBlue,
            navBarTranslucent: true,
            navBarOpaque: true,
            navBarTitleColor: .black,
            navShadowImage: UIImage(),
            navBackgroundImage: UIImage(),
            statusBarStyle: .default)
    }
}

struct CDIChallengeTheme: ChallengeTheme {

    var topBarBackgroundColor: UIColor {
        .white
    }

    var topBarContentColor: UIColor {
        .white
    }

    var navigation: CDINavigationStyle {
        CDINavigationStyle(
            viewBackgroundColor: .darkest(),
            navBarBackgroundColor: .darkest(),
            navBarColor: .darkest(),
            navBarTintColor: .white,
            navBarTranslucent: false,
            navBarOpaque: true,
            navBarTitleColor: .white,
            navShadowImage: UIImage(),
            navBackgroundImage: UIImage(),
            statusBarStyle: .lightContent)
    }
}

struct CDIDiaryTheme: DiaryTheme {
    
    var topBarBackgroundColor: UIColor {
        .darkest()
    }
    
    var topBarContentColor: UIColor {
        .white
    }
    
    var navigation: CDINavigationStyle {
        CDINavigationStyle(
            viewBackgroundColor: .darkest(),
            navBarBackgroundColor: .darkest(),
            navBarColor: .darkest(),
            navBarTintColor: .white,
            navBarTranslucent: false,
            navBarOpaque: true,
            navBarTitleColor: .white,
            navShadowImage: UIImage(),
            navBackgroundImage: UIImage(),
            statusBarStyle: .lightContent)
    }
}

struct CDIJourneyTheme: JourneyTheme {
    
    var topBarBackgroundColor: UIColor {
        .black40()
    }
    
    var topBarContentColor: UIColor {
        .black40()
    }
    
    var navigation: CDINavigationStyle {
        CDINavigationStyle(
            viewBackgroundColor: .black40(),
            navBarBackgroundColor: .black40(),
            navBarColor: .black40(),
            navBarTintColor: .black40(),
            navBarTranslucent: false,
            navBarOpaque: true,
            navBarTitleColor: .white,
            navShadowImage: UIImage(),
            navBackgroundImage: UIImage(),
            statusBarStyle: .lightContent)
    }
}

struct CDIMeditationTheme: MeditationTheme {
    
    var tintColor: UIColor {
        .pure()
    }
    
    var accentColor: UIColor {
        .black40()
    }
    
    var navigation: CDINavigationStyle {
        CDINavigationStyle(
            viewBackgroundColor: .white,
            navBarBackgroundColor: .white,
            navBarColor: .white,
            navBarTintColor: .systemBlue,
            navBarTranslucent: true,
            navBarOpaque: true,
            navBarTitleColor: .black,
            navShadowImage: UIImage(),
            navBackgroundImage: UIImage(),
            statusBarStyle: .default)
    }
}

struct CDIMealTheme: MealTheme {
    
    var navigation: CDINavigationStyle {
        CDINavigationStyle(
            viewBackgroundColor: .black40(),
            navBarBackgroundColor: .black40(),
            navBarColor: .black40(),
            navBarTintColor: .white,
            navBarTranslucent: false,
            navBarOpaque: true,
            navBarTitleColor: .white,
            navShadowImage: UIImage(),
            navBackgroundImage: UIImage(),
            statusBarStyle: .lightContent)
    }
}

struct CDIConfigTheme: ConfigTheme {
    
    var navigation: CDINavigationStyle {
        CDINavigationStyle(
            viewBackgroundColor: .black40(),
            navBarBackgroundColor: .black40(),
            navBarColor: .black40(),
            navBarTintColor: .white,
            navBarTranslucent: false,
            navBarOpaque: true,
            navBarTitleColor: .white,
            navShadowImage: UIImage(),
            navBackgroundImage: UIImage(),
            statusBarStyle: .lightContent)
    }
}

struct CDIVitatTheme: VitatTheme {
    
    var topBarBackgroundColor: UIColor {
        .white
    }
    
    var topBarContentColor: UIColor {
        .white
    }
    
    var navigation: CDINavigationStyle {
        CDINavigationStyle(viewBackgroundColor: .white,
                           navBarBackgroundColor: .white,
                           navBarColor: .white,
                           navBarTintColor: .black,
                           navBarTranslucent: false,
                           navBarOpaque: true,
                           navBarTitleColor: .black,
                           navShadowImage: UIImage(),
                           navBackgroundImage: UIImage(),
                           statusBarStyle: .default)
    }
    
}
struct CDIMeetTheme: MeetTheme {
    var controlsViewColor: UIColor = .darkest()
    
    var userInfoLabelText: UIColor = .black
    
    var micButton: UIImage? {
        UIImage(named: "ic_mic")
    }
    
    var disabledMicButton: UIImage? {
        UIImage(named: "ic_mic_muted")
    }
    
    var videoButton: UIImage? {
        UIImage(named: "ic_cam")
    }

    var disabledVideoButton: UIImage? {
        UIImage(named: "ic_cam_off")
    }
    
    var navigation: CDINavigationStyle {
        return CDINavigationStyle(
            viewBackgroundColor: .white,
            navBarBackgroundColor: .white,
            navBarColor: .white,
            navBarTintColor: .white,
            navBarTranslucent: false,
            navBarOpaque: true,
            navBarTitleColor: .white,
            navShadowImage: UIImage(),
            navBackgroundImage: UIImage(),
            statusBarStyle: .lightContent
        )
    }
    
}


